==> ktorrent-2.1rc1.tar.bz2: ktorrent-2.1rc1/libktorrent/ktversion.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Joris Guisson                                   *
 *   joris.guisson@gmail.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
 ***************************************************************************/
#ifndef KTVERSION_HH
#define KTVERSION_HH


#include "util/constants.h"

namespace kt
{
	const bt::Uint32 MAJOR = 2;
	const bt::Uint32 MINOR = 1;
	const char VERSION_STRING[] = "2.1rc1";
	const char PEER_ID[] = "-KT21R1-";
}



#endif

==> ktorrent-2.1.3.tar.bz2: ktorrent-2.1.3/libktorrent/ktversion.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Joris Guisson                                   *
 *   joris.guisson@gmail.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
 ***************************************************************************/
#ifndef KTVERSION_HH
#define KTVERSION_HH


#include "util/constants.h"

namespace kt
{
	const bt::Uint32 MAJOR = 2;
	const bt::Uint32 MINOR = 1;
	const char VERSION_STRING[] = "2.1.3";
	const char PEER_ID[] = "-KT2130-";
}

#define KT_VERSION_MACRO "2.1.3"

#endif
